# _*_ coding: utf-8 _*_
#
# hspylib-clitt v0.9.43
#
# Package: main.clitt
"""Package initialization."""

__all__ = [
  'addons', 
  'core'
]
__version__ = '0.9.43'
